/**
  *  \file client/screens/ionscreen.cc
  *  \brief Ion Storm Information Screen
  *
  *  (c) 2001-2013 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/screens/ionscreen.h"
#include "client/tiles/ioninfo.h"
#include "client/tiles/objheader.h"
#include "cpluslib/format.h"
#include "game/formula.h"
#include "game/global.h"
#include "game/ion.h"
#include "game/objtypes.h"
#include "gfx/palette.h"
#include "int/if/userif.h"
#include "ui/layout.h"
#include "ui/uiglobal.h"
#include "ui/window.h"
#include "util/nls.h"
#include "client/widgets/objcontrol.h"
#include "ui/widgets/button.h"
#include "client/screens.h"

namespace {
    class WIonStormInfoWindow : public UIWindow {
        ObjectHolder h;
        GObjectSelection& selection;
     public:
        WIonStormInfoWindow(GObjectSelection& selection);
    };
}

/************************** WIonStormInfoWindow **************************/

WIonStormInfoWindow::WIonStormInfoWindow(GObjectSelection& selection)
    : UIWindow(_("Ion Storm Information"), BLUE_WINDOW, COLOR_GRAY),
      selection(selection)
{
    // VBox
    //   WObjectSelectionHeaderTile
    //   WIonStormInfoTile
    //   HBox
    //     Close GoTo Forecast <--> H
    // Difference to PCC 1.x: Up/Down are in WObjectSelectionHeaderTile
    setLayout(UIVBoxLayout::instance5);

    UIGroup& g1 = h.add(new UIGroup(UIHBoxLayout::instance5));

    g1.add(h.add(new UIButton(0, _("Close"), SDLK_ESCAPE)).addStop());
    g1.add(h.add(new UIButton(1, _("Go To"), SDLK_RETURN)).addStop());
    g1.add(h.add(new UISpacer()));

    add(h.add(new WObjectSelectionHeaderTile(selection)));
    add(h.add(new WIonStormInfoTile(selection)));
    add(g1);
    add(h.add(new WObjectSelectionControl(selection)));

    pack();
}

/** Ion storm information screen. Displays the ion storm currently
    selected in current_ion_selection. */
void
doIonStormScreen()
{
    if (current_ion_type.isEmpty())
        return;

    WIonStormInfoWindow win(current_ion_selection);
    ui_root->centerWidget(win);
    int result = ui_root->runModal(win);
    if (result == 1) {
        // "Go to"
        if (GMapObject* mo = dynamic_cast<GMapObject*>(current_ion_selection.getCurrentObject())) {
            postGoToChart(IntUserInterfaceBinding::get(), mo->getPos());
        }
    }
}
