/**
  *  \file client/widgets/objcontrol.cc
  *  \brief WObjectSelectionControl widget
  *
  *  (c) 2001-2013 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/widgets/objcontrol.h"
#include "game/obj.h"
#include "game/objtypes.h"
#include "game/univ.h"

WObjectSelectionControl::WObjectSelectionControl(GObjectSelection& selection)
    : UIFixedWidget(),
      selection(selection)
{ }

bool
WObjectSelectionControl::handleEvent(const UIEvent& event, bool second_pass)
{
    if (event.type == ev_Key) {
        switch (event.key.code) {
         case SDLK_PAGEUP:
         case SDLK_UP:
         case vk_WheelUp:
         case '-':
            if (int i = selection.getObjectType()->findPreviousIndexWrap(selection.getCurrentIndex(), false)) {
                selection.setCurrentIndex(i);
            }
            return true;
         case SDLK_PAGEDOWN:
         case SDLK_DOWN:
         case vk_WheelDown:
         case '+':
            if (int i = selection.getObjectType()->findNextIndexWrap(selection.getCurrentIndex(), false)) {
                selection.setCurrentIndex(i);
            }
            return true;
         case ss_Ctrl + SDLK_PAGEUP:
         case ss_Ctrl + SDLK_UP:
            if (int i = selection.getObjectType()->findPreviousIndexWrap(selection.getCurrentIndex(), true)) {
                selection.setCurrentIndex(i);
            }
            return true;
         case ss_Ctrl + SDLK_PAGEDOWN:
         case ss_Ctrl + SDLK_DOWN:
            if (int i = selection.getObjectType()->findNextIndexWrap(selection.getCurrentIndex(), true)) {
                selection.setCurrentIndex(i);
            }
            return true;
         case SDLK_HOME:
            if (int i = selection.getObjectType()->findNextIndexNoWrap(0, false)) {
                selection.setCurrentIndex(i);
            }
            return true;
         case SDLK_END:
            if (int i = selection.getObjectType()->findPreviousIndexNoWrap(0, false)) {
                selection.setCurrentIndex(i);
            }
            return true;
         case ss_Ctrl + SDLK_HOME:
            if (int i = selection.getObjectType()->findNextIndexNoWrap(0, true)) {
                selection.setCurrentIndex(i);
            }
            return true;
         case ss_Ctrl + SDLK_END:
            if (int i = selection.getObjectType()->findPreviousIndexNoWrap(0, true)) {
                selection.setCurrentIndex(i);
            }
            return true;
         case '.':
            if (GObject* obj = selection.getCurrentObject()) {
                obj->setIsMarked(!obj->isMarked());
                selection.getCurrentUniverse()->doScreenUpdates();
            }
            return true;
        }
    }
    return UIFixedWidget::handleEvent(event, second_pass);
}

void
WObjectSelectionControl::drawContent(GfxCanvas& /*can*/)
{ }
