/**
  *  \file int/special.cc
  *  \brief Interpreter: Special Commands
  *
  *  This is an interface to extend the compiler with new special
  *  commands without having to modify the actual compiler.
  *
  *  (c) 2001-2013 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "int/special.h"
#include "int/interror.h"
#include "int/intglobal.h"
#include "int/names.h"
#include "int/data.h"
#include "cpluslib/ptrmap.h"
#include "int/if/ifutil.h"
#include "int/propenum.h"

IntSpecialCommand::~IntSpecialCommand()
{ }


IntSimpleSpecialCommand::IntSimpleSpecialCommand(compile_t function)
    : function(function)
{ }

IntSimpleSpecialCommand::~IntSimpleSpecialCommand()
{ }

void
IntSimpleSpecialCommand::compileCommand(IntTokenizer& line, IntBytecodeObject& bco, const IntStatementCompilationContext& scc)
{
    function(line, bco, scc);
}



/**************************** Name Management ****************************/

static ptr_map<string_t,IntSpecialCommand> special_commands;

/** Define a special command.
    \param name   [in] Name of the command, upper-case
    \param newCmd [in] Newly-created IntSpecialCommand descendant object */
void
defineSpecialCommand(const char* name, IntSpecialCommand* newCmd)
{
    special_commands.insert(name, newCmd);
}

/** Look up special command.
    \param name Name of command
    \return IntSpecialCommand descendant that compiles this command.
    0 if this is not a special command. */
IntSpecialCommand*
lookupSpecialCommand(string_t name)
{
    return special_commands[name];
}

void
enumSpecialCommands(IntPropertyAcceptor& acceptor)
{
    for (ptr_map<string_t,IntSpecialCommand>::iterator i = special_commands.begin(); i != special_commands.end(); ++i) {
        acceptor.addProperty(i->first, thNone);
    }
}
