/**
  *  \file ui/widgets/inputline.h
  *
  *  (c) 2001-2013 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_UI_WIDGETS_INPUTLINE_H
#define PCC_V2_UI_WIDGETS_INPUTLINE_H

#include "cpluslib/string.h"
#include "ui/ui.h"

class UIInputLine : public UIWidget {
 public:
    typedef string_t::size_type pos_type;
 private:
    UIKey     hotkey;
    pos_type  maxlen;
    pos_type  curx, firstx;
    string_t  text;
    int       font;
    int       pref_len;         // preferred length in em
    void scroll();
    int getTextWidth();
    int getTextHeight();
    bool acceptUnicode(uint32_t uni) const;
    enum {
        CursorWidth = 2
    };
 public:
    enum {
        ilf_NumbersOnly = 2*st_Last,    // accept only digits
        ilf_Framed      = 4*st_Last,    // show frame
        ilf_Hidden      = 8*st_Last,    // "star out" text
        ilf_NoHi        = 16*st_Last,   // don't accept high-ascii chars
        ilf_NonEditable = 32*st_Last,   // non-editable
        ilf_Notify      = 64*st_Last,   // generate cm_TypeNotify events
        ilf_TypeErase   = 128*st_Last,
        ilf_GameChars   = 256*st_Last   // only characters from game charset
    };
    UIInputLine(string_t::size_type amaxl, UIKey ahot, int aflags, int aid);
    UIInputLine(string_t::size_type amaxl, int apref_len, UIKey ahot, int aflags, int aid);
    void setText(string_t s);
    string_t getText() const { return text; }

    bool handleEvent(const UIEvent& e, bool second_pass);
    void drawContent(GfxCanvas& can);
    void insert(string_t s);
    void setCursor(pos_type);
    pos_type getCursor() const;
    void onStateChange(int astate, bool enable);

    void getLayoutInfo(LayoutInfo& info);

    static bool run(string_t& str, string_t::size_type maxlen,
                    const string_t& title, const string_t& req,
                    int width, int flags);

    Signal1<int> sig_changed;
};

#endif
